@@ -84,29 +84,7 @@ def n0print(
     :param internal_call:
     :return: None
     """
-
-    '''
-    if internal_call:  # Called from n0debug|n0debug_calc|n0debug_object
-        try:
-            frameinfo = inspect.stack()[3]
-        except:
-            try:
-                frameinfo = inspect.stack()[2]
-            except:
-                try:
-                    frameinfo = inspect.stack()[1]
-                except:
-                    try:
-                        frameinfo = inspect.stack()[0]
-                    except:
-                        frameinfo = None
-    else:
-        frameinfo = inspect.getframeinfo(inspect.currentframe().f_back)
-    '''
-
-    logger.opt(depth=1+internal_call).log(level,
-        (text if text else "")
-    )
+    logger.opt(depth=1+internal_call).log(level, text or "")
 # ******************************************************************************
 def n0info(text: str, internal_call: int = 0):
     n0print(text, level = "INFO", internal_call = internal_call + 1)
@@ -142,7 +120,7 @@ def n0pretty(
             if not isinstance(sub_item, dict) or len(sub_item) > 2:
                 return None # Sub element not dictionary with 2 or less elements
             for key in sub_item:
-                if not key in element_names:
+                if key not in element_names:
                     element_names.update({key: 0})
                 if len(element_names) > 2:
                     return None # Not more that 2 elems could be condensed into one line
@@ -163,7 +141,6 @@ def n0pretty(
                         if isinstance(sub_item_key_value, str)
                         else f"{str(sub_item_key_value)}"
                     )
-                # print(f"{len(presentation_string)} {presentation_string=}")
                 element_names.update({key: max(element_names[key], len(presentation_string))})
         return element_names  # Returns dict {"name of key": max length of presented (+type+len and etc) value assosiated with key}
     # ######################################################################
@@ -230,7 +207,6 @@ def n0pretty(
                         if sub_result:
                             sub_result += " "
                         sub_result += " "*(1+len(__quotes)+len(key)+len(__quotes)+len(": ")+keys_and_max_len_of_value[key])
-                        # raise Exception(f"Nonsense: '{key}' is not found in '{sub_item}'")
                 result += sub_result + " }"
         else:
             # dict, set, frozenset or list/tuple with complex or not paired structure
@@ -296,7 +272,7 @@ def n0pretty(
                     else:
                         sub_item_value = "[.......]"
 
-                if not sub_item_value is None:
+                if sub_item_value is not None:
                     if result:
                         result += "," + indent()
                     result += sub_item_value
@@ -326,12 +302,6 @@ def n0pretty(
             else:
                 result = result_type + brackets[0] + result + brackets[1]
 
-        # I suppose never used
-        # if not result:
-        #     if json_convention:
-        #         result = "null"  # json.decoder.JSONDecodeError: Expecting value
-        #     else:
-        #         result = None
         if result is None and json_convention:
             result = "null"  # json.decoder.JSONDecodeError: Expecting value
 
@@ -339,7 +309,7 @@ def n0pretty(
         if (show_type or (show_type is None and __debug_show_object_type)) \
         and (not skip_simple_types or not isinstance(item, (str, int, float))):
             result_type = (str(type(item)) or "").replace("<class '", "<").replace("'>", " ") + f"{len(item)}> "
-        if auto_quotes and '"' in item and not "'" in item:
+        if auto_quotes and '"' in item and "'" not in item:
                 result = result_type + f"'{item}'"
         else:
             result = result_type + __quotes + item.replace(__quotes, '\\"' if __quotes == '"' else "\\'") + __quotes
@@ -424,11 +394,11 @@ def n0debug(var_name: str, level: str = "DEBUG",
     :return:
     """
     if not isinstance(var_name,str):
-        raise Exception("incorrect call of n0debug(..): argument MUST BE string")
+        raise TypeError("incorrect call of n0debug(..): argument MUST BE string")
 
     __f_locals = inspect.currentframe().f_back.f_locals
-    if not var_name in __f_locals:
-        raise Exception("impossible to find object '%s'" % var_name)
+    if var_name not in __f_locals:
+        raise NameError("impossible to find object '%s'" % var_name)
     var_object = __f_locals.get(var_name)
     n0debug_calc(
         var_object, var_name,
